pub(super) struct FxHasher {
hash: usize,
}🔬This is a nightly-only experimental API. (
proc_macro_internals)Expand description
A speedy hash algorithm for use within rustc. The hashmap in alloc by default uses SipHash which isn’t quite as speedy as we want. In the compiler we’re not really worried about DOS attempts, so we use a fast non-cryptographic hash.
This is the same as the algorithm used by Firefox – which is a homespun one not based on any widely-known algorithm – though modified to produce 64-bit hash values instead of 32-bit hash values. It consistently out-performs an FNV-based hash within rustc itself – the collision rate is similar or slightly worse than FNV, but the speed of the hash function itself is much higher because it works on up to 8 bytes at a time.
Fields
hash: usize🔬This is a nightly-only experimental API. (
proc_macro_internals)Implementations